@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+from future.builtins import range
 
 from mezzanine.conf import settings
 from mezzanine.core.managers import DisplayableManager
