@@ -5,6 +5,12 @@ from datetime import datetime, timedelta
 import re
 from time import timezone
 
+try:
+    from urllib.parse import quote
+except ImportError:
+    # Python 2
+    from urllib import quote
+
 from django.db import models
 from django.utils.encoding import python_2_unicode_compatible
 from django.utils.html import urlize
@@ -50,15 +56,18 @@ class Query(models.Model):
         """
         Request new tweets from the Twitter API.
         """
+        try:
+            value = quote(self.value)
+        except KeyError:
+            value = self.value
         urls = {
             QUERY_TYPE_USER: ("https://api.twitter.com/1.1/statuses/"
                               "user_timeline.json?screen_name=%s"
-                              "&include_rts=true" %
-                              self.value.lstrip("@")),
+                              "&include_rts=true" % value.lstrip("@")),
             QUERY_TYPE_LIST: ("https://api.twitter.com/1.1/lists/statuses.json"
-                              "?list_id=%s&include_rts=true" % self.value),
+                              "?list_id=%s&include_rts=true" % value),
             QUERY_TYPE_SEARCH: "https://api.twitter.com/1.1/search/tweets.json"
-                                "?q=%s" % self.value,
+                                "?q=%s" % value,
         }
         try:
             url = urls[self.type]
